# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/config/mongodb3_6.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mongodb/v1/config/mongodb3_6.proto',
  package='yandex.cloud.mdb.mongodb.v1.config',
  syntax='proto3',
  serialized_pb=_b('\n3yandex/cloud/mdb/mongodb/v1/config/mongodb3_6.proto\x12\"yandex.cloud.mdb.mongodb.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x9e\x0b\n\x0fMongodConfig3_6\x12L\n\x07storage\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage\x12\x63\n\x13operation_profiling\x18\x02 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.OperationProfiling\x12H\n\x03net\x18\x03 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Network\x1a\xc6\x06\n\x07Storage\x12[\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger\x12T\n\x07journal\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.Journal\x1a\x8e\x04\n\nWiredTiger\x12j\n\rengine_config\x18\x01 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.EngineConfig\x12r\n\x11\x63ollection_config\x18\x02 \x01(\x0b\x32W.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.CollectionConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xda\x01\n\x10\x43ollectionConfig\x12|\n\x10\x62lock_compressor\x18\x01 \x01(\x0e\x32\x62.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.CollectionConfig.Compressor\"H\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06SNAPPY\x10\x02\x12\x08\n\x04ZLIB\x10\x03\x1aw\n\x07Journal\x12+\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0f\x63ommit_interval\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-500\x1a\xec\x01\n\x12OperationProfiling\x12Y\n\x04mode\x18\x01 \x01(\x0e\x32K.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xfa\x01\n\x12MongodConfigSet3_6\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6BPZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodbb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR = _descriptor.EnumDescriptor(
  name='Compressor',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.CollectionConfig.Compressor',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPRESSOR_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SNAPPY', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZLIB', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1073,
  serialized_end=1145,
)
_sym_db.RegisterEnumDescriptor(_MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR)

_MONGODCONFIG3_6_OPERATIONPROFILING_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.OperationProfiling.Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SLOW_OP', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1446,
  serialized_end=1505,
)
_sym_db.RegisterEnumDescriptor(_MONGODCONFIG3_6_OPERATIONPROFILING_MODE)


_MONGODCONFIG3_6_STORAGE_WIREDTIGER_ENGINECONFIG = _descriptor.Descriptor(
  name='EngineConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.EngineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_size_gb', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.EngineConfig.cache_size_gb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=924,
)

_MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG = _descriptor.Descriptor(
  name='CollectionConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.CollectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_compressor', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.CollectionConfig.block_compressor', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=1145,
)

_MONGODCONFIG3_6_STORAGE_WIREDTIGER = _descriptor.Descriptor(
  name='WiredTiger',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.engine_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.collection_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG3_6_STORAGE_WIREDTIGER_ENGINECONFIG, _MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=1145,
)

_MONGODCONFIG3_6_STORAGE_JOURNAL = _descriptor.Descriptor(
  name='Journal',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.Journal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.Journal.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit_interval', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.Journal.commit_interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\0051-500')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1147,
  serialized_end=1266,
)

_MONGODCONFIG3_6_STORAGE = _descriptor.Descriptor(
  name='Storage',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wired_tiger', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.wired_tiger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='journal', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.journal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG3_6_STORAGE_WIREDTIGER, _MONGODCONFIG3_6_STORAGE_JOURNAL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=1266,
)

_MONGODCONFIG3_6_OPERATIONPROFILING = _descriptor.Descriptor(
  name='OperationProfiling',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.OperationProfiling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.OperationProfiling.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slow_op_threshold', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.OperationProfiling.slow_op_threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\002>0')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGODCONFIG3_6_OPERATIONPROFILING_MODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1269,
  serialized_end=1505,
)

_MONGODCONFIG3_6_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\01010-16384')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1593,
)

_MONGODCONFIG3_6 = _descriptor.Descriptor(
  name='MongodConfig3_6',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation_profiling', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.operation_profiling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.net', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG3_6_STORAGE, _MONGODCONFIG3_6_OPERATIONPROFILING, _MONGODCONFIG3_6_NETWORK, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=1593,
)


_MONGODCONFIGSET3_6 = _descriptor.Descriptor(
  name='MongodConfigSet3_6',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet3_6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet3_6.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet3_6.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet3_6.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1596,
  serialized_end=1846,
)

_MONGODCONFIG3_6_STORAGE_WIREDTIGER_ENGINECONFIG.fields_by_name['cache_size_gb'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_MONGODCONFIG3_6_STORAGE_WIREDTIGER_ENGINECONFIG.containing_type = _MONGODCONFIG3_6_STORAGE_WIREDTIGER
_MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG.fields_by_name['block_compressor'].enum_type = _MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR
_MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG.containing_type = _MONGODCONFIG3_6_STORAGE_WIREDTIGER
_MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR.containing_type = _MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG
_MONGODCONFIG3_6_STORAGE_WIREDTIGER.fields_by_name['engine_config'].message_type = _MONGODCONFIG3_6_STORAGE_WIREDTIGER_ENGINECONFIG
_MONGODCONFIG3_6_STORAGE_WIREDTIGER.fields_by_name['collection_config'].message_type = _MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG
_MONGODCONFIG3_6_STORAGE_WIREDTIGER.containing_type = _MONGODCONFIG3_6_STORAGE
_MONGODCONFIG3_6_STORAGE_JOURNAL.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MONGODCONFIG3_6_STORAGE_JOURNAL.fields_by_name['commit_interval'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG3_6_STORAGE_JOURNAL.containing_type = _MONGODCONFIG3_6_STORAGE
_MONGODCONFIG3_6_STORAGE.fields_by_name['wired_tiger'].message_type = _MONGODCONFIG3_6_STORAGE_WIREDTIGER
_MONGODCONFIG3_6_STORAGE.fields_by_name['journal'].message_type = _MONGODCONFIG3_6_STORAGE_JOURNAL
_MONGODCONFIG3_6_STORAGE.containing_type = _MONGODCONFIG3_6
_MONGODCONFIG3_6_OPERATIONPROFILING.fields_by_name['mode'].enum_type = _MONGODCONFIG3_6_OPERATIONPROFILING_MODE
_MONGODCONFIG3_6_OPERATIONPROFILING.fields_by_name['slow_op_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG3_6_OPERATIONPROFILING.containing_type = _MONGODCONFIG3_6
_MONGODCONFIG3_6_OPERATIONPROFILING_MODE.containing_type = _MONGODCONFIG3_6_OPERATIONPROFILING
_MONGODCONFIG3_6_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG3_6_NETWORK.containing_type = _MONGODCONFIG3_6
_MONGODCONFIG3_6.fields_by_name['storage'].message_type = _MONGODCONFIG3_6_STORAGE
_MONGODCONFIG3_6.fields_by_name['operation_profiling'].message_type = _MONGODCONFIG3_6_OPERATIONPROFILING
_MONGODCONFIG3_6.fields_by_name['net'].message_type = _MONGODCONFIG3_6_NETWORK
_MONGODCONFIGSET3_6.fields_by_name['effective_config'].message_type = _MONGODCONFIG3_6
_MONGODCONFIGSET3_6.fields_by_name['user_config'].message_type = _MONGODCONFIG3_6
_MONGODCONFIGSET3_6.fields_by_name['default_config'].message_type = _MONGODCONFIG3_6
DESCRIPTOR.message_types_by_name['MongodConfig3_6'] = _MONGODCONFIG3_6
DESCRIPTOR.message_types_by_name['MongodConfigSet3_6'] = _MONGODCONFIGSET3_6
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MongodConfig3_6 = _reflection.GeneratedProtocolMessageType('MongodConfig3_6', (_message.Message,), dict(

  Storage = _reflection.GeneratedProtocolMessageType('Storage', (_message.Message,), dict(

    WiredTiger = _reflection.GeneratedProtocolMessageType('WiredTiger', (_message.Message,), dict(

      EngineConfig = _reflection.GeneratedProtocolMessageType('EngineConfig', (_message.Message,), dict(
        DESCRIPTOR = _MONGODCONFIG3_6_STORAGE_WIREDTIGER_ENGINECONFIG,
        __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.EngineConfig)
        ))
      ,

      CollectionConfig = _reflection.GeneratedProtocolMessageType('CollectionConfig', (_message.Message,), dict(
        DESCRIPTOR = _MONGODCONFIG3_6_STORAGE_WIREDTIGER_COLLECTIONCONFIG,
        __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger.CollectionConfig)
        ))
      ,
      DESCRIPTOR = _MONGODCONFIG3_6_STORAGE_WIREDTIGER,
      __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.WiredTiger)
      ))
    ,

    Journal = _reflection.GeneratedProtocolMessageType('Journal', (_message.Message,), dict(
      DESCRIPTOR = _MONGODCONFIG3_6_STORAGE_JOURNAL,
      __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage.Journal)
      ))
    ,
    DESCRIPTOR = _MONGODCONFIG3_6_STORAGE,
    __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Storage)
    ))
  ,

  OperationProfiling = _reflection.GeneratedProtocolMessageType('OperationProfiling', (_message.Message,), dict(
    DESCRIPTOR = _MONGODCONFIG3_6_OPERATIONPROFILING,
    __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.OperationProfiling)
    ))
  ,

  Network = _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), dict(
    DESCRIPTOR = _MONGODCONFIG3_6_NETWORK,
    __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6.Network)
    ))
  ,
  DESCRIPTOR = _MONGODCONFIG3_6,
  __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6)
  ))
_sym_db.RegisterMessage(MongodConfig3_6)
_sym_db.RegisterMessage(MongodConfig3_6.Storage)
_sym_db.RegisterMessage(MongodConfig3_6.Storage.WiredTiger)
_sym_db.RegisterMessage(MongodConfig3_6.Storage.WiredTiger.EngineConfig)
_sym_db.RegisterMessage(MongodConfig3_6.Storage.WiredTiger.CollectionConfig)
_sym_db.RegisterMessage(MongodConfig3_6.Storage.Journal)
_sym_db.RegisterMessage(MongodConfig3_6.OperationProfiling)
_sym_db.RegisterMessage(MongodConfig3_6.Network)

MongodConfigSet3_6 = _reflection.GeneratedProtocolMessageType('MongodConfigSet3_6', (_message.Message,), dict(
  DESCRIPTOR = _MONGODCONFIGSET3_6,
  __module__ = 'yandex.cloud.mdb.mongodb.v1.config.mongodb3_6_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet3_6)
  ))
_sym_db.RegisterMessage(MongodConfigSet3_6)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('ZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodb'))
_MONGODCONFIG3_6_STORAGE_JOURNAL.fields_by_name['commit_interval'].has_options = True
_MONGODCONFIG3_6_STORAGE_JOURNAL.fields_by_name['commit_interval']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\0051-500'))
_MONGODCONFIG3_6_OPERATIONPROFILING.fields_by_name['slow_op_threshold'].has_options = True
_MONGODCONFIG3_6_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\002>0'))
_MONGODCONFIG3_6_NETWORK.fields_by_name['max_incoming_connections'].has_options = True
_MONGODCONFIG3_6_NETWORK.fields_by_name['max_incoming_connections']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\01010-16384'))
# @@protoc_insertion_point(module_scope)
