# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/user_account.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iam/v1/user_account.proto',
  package='yandex.cloud.iam.v1',
  syntax='proto3',
  serialized_pb=_b('\n&yandex/cloud/iam/v1/user_account.proto\x12\x13yandex.cloud.iam.v1\x1a\x1dyandex/cloud/validation.proto\"\x81\x01\n\x0bUserAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12V\n\x1cyandex_passport_user_account\x18\x02 \x01(\x0b\x32..yandex.cloud.iam.v1.YandexPassportUserAccountH\x00\x42\x0e\n\x0cuser_account\"A\n\x19YandexPassportUserAccount\x12\r\n\x05login\x18\x01 \x01(\t\x12\x15\n\rdefault_email\x18\x02 \x01(\tB=Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_USERACCOUNT = _descriptor.Descriptor(
  name='UserAccount',
  full_name='yandex.cloud.iam.v1.UserAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iam.v1.UserAccount.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yandex_passport_user_account', full_name='yandex.cloud.iam.v1.UserAccount.yandex_passport_user_account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='user_account', full_name='yandex.cloud.iam.v1.UserAccount.user_account',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=95,
  serialized_end=224,
)


_YANDEXPASSPORTUSERACCOUNT = _descriptor.Descriptor(
  name='YandexPassportUserAccount',
  full_name='yandex.cloud.iam.v1.YandexPassportUserAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='login', full_name='yandex.cloud.iam.v1.YandexPassportUserAccount.login', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_email', full_name='yandex.cloud.iam.v1.YandexPassportUserAccount.default_email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=291,
)

_USERACCOUNT.fields_by_name['yandex_passport_user_account'].message_type = _YANDEXPASSPORTUSERACCOUNT
_USERACCOUNT.oneofs_by_name['user_account'].fields.append(
  _USERACCOUNT.fields_by_name['yandex_passport_user_account'])
_USERACCOUNT.fields_by_name['yandex_passport_user_account'].containing_oneof = _USERACCOUNT.oneofs_by_name['user_account']
DESCRIPTOR.message_types_by_name['UserAccount'] = _USERACCOUNT
DESCRIPTOR.message_types_by_name['YandexPassportUserAccount'] = _YANDEXPASSPORTUSERACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserAccount = _reflection.GeneratedProtocolMessageType('UserAccount', (_message.Message,), dict(
  DESCRIPTOR = _USERACCOUNT,
  __module__ = 'yandex.cloud.iam.v1.user_account_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.UserAccount)
  ))
_sym_db.RegisterMessage(UserAccount)

YandexPassportUserAccount = _reflection.GeneratedProtocolMessageType('YandexPassportUserAccount', (_message.Message,), dict(
  DESCRIPTOR = _YANDEXPASSPORTUSERACCOUNT,
  __module__ = 'yandex.cloud.iam.v1.user_account_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.YandexPassportUserAccount)
  ))
_sym_db.RegisterMessage(YandexPassportUserAccount)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'))
# @@protoc_insertion_point(module_scope)
